Generates a PhoenixFilament resource for an Ecto schema.
Usage
mix phx_filament.gen.resource MyApp.Blog.Post
mix phx_filament.gen.resource MyApp.Blog.Post --repo MyApp.Repo.ReadOnlyWhat it does
- Creates a Resource module at
lib/{app_web}/admin/{name}_resource.ex - Attempts to register the resource in your Panel module automatically
- Falls back to printing instructions if the Panel module cannot be found or patched
Options
--repo/-r— Ecto Repo module to use. Auto-detected fromuse Ecto.Repomodules, defaults to{AppName}.Repoif none found.