Theme utilities for daisyUI 5 CSS variable theming.
Summary
Functions
Renders a daisyUI swap toggle that switches between light and dark themes via theme-controller.
Functions
Renders a daisyUI swap toggle that switches between light and dark themes via theme-controller.
Example
<.theme_switcher light_theme="light" dark_theme="dark" />Attributes
light_theme(:string) - Defaults to"light".dark_theme(:string) - Defaults to"dark".class(:string) - Defaults tonil.- Global attributes are accepted.